/* Grid Sequences by Jesus Ramos */

/*
 * Explanation : This is a maximization problem with optimal
 * substructure First I start by creating the grid/adjacency matrix
 * and placing all Node's into each. The priority queue is going to
 * sort them from largest value to smallest. Consider starting not
 * knowing any path's whatsoever I set the length of all paths from
 * all nodes to 0. For every node we can write the length of the
 * longest path to that node as a relation Length of longest path at
 * node = 1 (value of path including only this node) + length of
 * longest path found by checking all adjacencies, If we do this for
 * all Node's then the Node that has the highest currentLength will be
 * the Node that is a part of the longest sequence and all you have to
 * do is iterate this sequence to get the actual path
 */

/*
 * The printing of the longest path was removed for the competition to
 * make the problem slightly easier to code and to judge as there
 * could easily exist multiple longest paths in such a grid and
 * verifying uniqueness takes a while for judge data
 */

import java.io.*;
import java.util.*;

public class Grid
{
    static int longestPath = 0;
    static Node startNode;
    static Node[][] grid;
    static PriorityQueue<Node> queue = new PriorityQueue<Node>();
	
    public static void main(String[] args) throws FileNotFoundException
    {
        readGrid(args[0]);
        long start = System.currentTimeMillis();
        findLongestPath();
        long runtime = System.currentTimeMillis() - start;
        traceLongestPath();
        System.out.printf("Elapsed time = %d ms\n", runtime);
    }

    static void traceLongestPath()
    {
        System.out.printf("Length of the longest path = %d\n", longestPath);
        while (startNode != null)
        {
            System.out.println(startNode);
            startNode = startNode.nextNode;
        }
    }

    static void findLongestPath()
    {
        while (!queue.isEmpty())
        {
            Node n = queue.poll();
            findLongestAdjacentPath(n);
            if (n.currentLength > longestPath)
            {
                longestPath = n.currentLength;
                startNode = n;
            }
        }
    }

    static void findLongestAdjacentPath(Node n)
    {
        int maxR = -1;
        int maxC = -1;
        int row = n.r;
        int col = n.c;
        int max = 0;

        for (int i = -1; i <= 1; i++)
            for (int j = -1; j <= 1; j++)
                if (i != 0 || j != 0)
                    if (inBound(row + i, col + j) && grid[row + i][col + j].val != n.val)
                    {
                        int length = grid[row + i][col + j].currentLength;
                        if (length > max)
                        {
                            maxR = row + i;
                            maxC = col + j;
                            max = length;
                        }
                    }
        n.currentLength = 1 + max;
        if (maxR != -1 && maxC != -1)
            n.nextNode = grid[maxR][maxC];
    }

    static boolean inBound(int r, int c)
    {
        return r >= 0 && r < grid.length && c >= 0 && c < grid[0].length;
    }

    static void readGrid(String fileName) throws FileNotFoundException
    {
        Scanner in = new Scanner(new FileReader(fileName));
        ArrayList<String> lines = new ArrayList<String>();
        while (in.hasNextLine())
            lines.add(in.nextLine());
        int numRows = lines.size();
        int numColumns = lines.get(0).split(" ").length;
        grid = new Node[numRows][numColumns];
        for (int i = 0; i < numRows; i++)
        {
            Scanner lineScanner = new Scanner(lines.get(i));
            for (int j = 0; j < numColumns; j++)
            {
                grid[i][j] = new Node(lineScanner.nextInt(), i, j);
                queue.add(grid[i][j]);
            }
        }
    }
}
class Node implements Comparable<Node>
{
    public int val;
    public int currentLength = 0;
    public int r, c;
    public Node nextNode;

    public Node(int v, int row, int col)
    {
        val = v;
        r = row;
        c = col;
    }
	
    public int compareTo(Node n)
    {
        return n.val - this.val;
    }

    public String toString()
    {
        return String.format("(%d,%d) with cost %d", r, c, val);
    }
}
