/* Popping Balloons in a Box by Jesus Ramos */

/*
 * Explanation: Rather simple geometry problem with the simplification
 * that you only have to check whether a point of the brick (the four
 * corners) reside within a balloon (circle). It's trivial to
 * calculate the other 2 points from the given points for the
 * brick. Checking for a collision between point and circle is simple
 * you just check whether the distance from the center of the circle
 * is less than or equal to the radius then it is considered a
 * collision.
 */

#include <stdio.h>
#include <math.h>

#define SQUARE(x1, x2) ((x2 - x1) * (x2 - x1))

struct point
{
    double x, y;
};

struct balloon
{
    struct point loc;
    double radius;
};

struct brick
{
    struct point bottom_left;
    struct point top_right;
};

double distance(struct point *p1, struct point *p2)
{
    return sqrt(SQUARE(p1->x, p2->x) + SQUARE(p1->y, p2->y));
}

int inside_balloon(struct point *point, struct balloon *balloon)
{
    return distance(point, &balloon->loc) <= balloon->radius;
}

int check_collision(struct brick *brick, struct balloon *balloon)
{
    struct point top_left;
    struct point bottom_right;

    /* Find points of the brick */
    
    top_left.x = brick->bottom_left.x;
    top_left.y = brick->top_right.y;
    
    bottom_right.x = brick->top_right.x;
    bottom_right.y = brick->bottom_left.y;

    return inside_balloon(&top_left, balloon) || inside_balloon(&bottom_right, balloon) ||
        inside_balloon(&brick->bottom_left, balloon) || inside_balloon(&brick->top_right, balloon);
}

int main()
{
    int m, n;
    unsigned int i, j;
    unsigned int num_popped;

    while (scanf("%d %d", &m, &n) != EOF && (m || n))
    {
        //struct balloon balloons[m];
        //struct brick bricks[n];

			  balloon * balloons = new balloon[m];	
				brick * bricks = new brick[n];

				num_popped = 0;

        /* Balloons */
        for (i = 0; i < m; i++)
            scanf("%lf %lf %lf", &balloons[i].loc.x, &balloons[i].loc.y,
                  &balloons[i].radius);

        /* Bricks */
        for (i = 0; i < n; i++)
            scanf("%lf %lf %lf %lf", &bricks[i].bottom_left.x, &bricks[i].bottom_left.y,
                  &bricks[i].top_right.x, &bricks[i].top_right.y);

        for (i = 0; i < m; i++)
            for (j = 0; j < n; j++)
                if (check_collision(&bricks[j], &balloons[i]))
                {
                    num_popped++;
                    break;
                }

        printf("Popped %u balloons\n", num_popped);
    }
    
    return 0;
}
