/* Brick Walls by Jesus Ramos */

/*
 * Explanation: Start with the base, wall of length 1. There is only
 * one way to arrange that and that's using a rectangle of height 2
 * and width 1. Now with walls of length 2 we can have 2 patterns, 2
 * rectangles upright next to each other or 2 laying on top of each
 * other. It can be observed that all other patterns can be derived
 * from these two.
 *
 * Take a wall of width n, there are 2 ways to start arranging the
 * wall. Using the first case where we use 1 rectangle which leaves us
 * to fill in a wall of width n - 1, and the 2nd way is to use the 2
 * rectangles stacked on top of each other which leaves us to fill in
 * a wall of width n - 2.
 *
 * So if we write this as a function of n we can derive a recurrence
 * relation f(n) as follows:
 *
 * f(n) = { 1,                   n = 1
 *        { 2,                   n = 2
 *        { f(n - 1) + f(n - 2), n > 2
 *
 * The neat thing about this is that this is simply the fibonacci
 * series shifted over by 1! Easy to solve if you use the bottom up
 * approach to generate the fibonacci numbers beforehand.
 */

#include <stdio.h>

unsigned long long fib[52];

void make_fibs()
{
    unsigned int i;
    fib[0] = 0;
    fib[1] = 1;
    for (i = 2; i < 52; i++)
        fib[i] = fib[i-1] + fib[i - 2];
}

int main()
{
    unsigned int n;
    make_fibs();
    while (scanf("%u", &n) && n)
        printf("%llu\n", fib[n + 1]);
    return 0;
}
